@@ -19,7 +19,8 @@
  * @brief curl easy handle defaults
  * @author Florian Dold
  */
-
+#include "platform.h"
+#include <taler/taler_curl_lib.h>
 #include "sync_api_curl_defaults.h"
 
 /**
@@ -43,10 +44,8 @@ SYNC_curl_easy_get_ (const char *url)
                  curl_easy_setopt (eh,
                                    CURLOPT_URL,
                                    url));
-  GNUNET_assert (CURLE_OK ==
-                 curl_easy_setopt (eh,
-                                   CURLOPT_FOLLOWLOCATION,
-                                   1L));
+  TALER_curl_set_secure_redirect_policy (eh,
+                                         url);
   GNUNET_assert (CURLE_OK ==
                  curl_easy_setopt (eh,
                                    CURLOPT_TCP_FASTOPEN,
