@@ -14,7 +14,7 @@
   Sync; see the file COPYING.GPL.  If not, see <http://www.gnu.org/licenses/>
 */
 /**
- * @file backend/sync-httpd_config.c
+ * @file sync/sync-httpd_config.c
  * @brief headers for /config handler
  * @author Christian Grothoff
  */
@@ -31,17 +31,6 @@
  *    to be created
  */
 
-/**
- * Manages a /config call.
- *
- * @param rh context of the handler
- * @param connection the MHD connection to handle
- * @param[in,out] connection_cls the connection's closure (can be updated)
- * @param upload_data upload data
- * @param[in,out] upload_data_size number of bytes (left) in @a upload_data
- * @param mi merchant backend instance, never NULL
- * @return MHD result code
- */
 MHD_RESULT
 SH_handler_config (struct SH_RequestHandler *rh,
                    struct MHD_Connection *connection,
@@ -54,6 +43,8 @@ SH_handler_config (struct SH_RequestHandler *rh,
     MHD_HTTP_OK,
     GNUNET_JSON_pack_string ("name",
                              "sync"),
+    GNUNET_JSON_pack_string ("implementation",
+                             "urn:net:taler:specs:sync:c-reference"),
     GNUNET_JSON_pack_uint64 ("storage_limit_in_megabytes",
                              SH_upload_limit_mb),
     TALER_JSON_pack_amount ("liability_limit",
@@ -61,7 +52,7 @@ SH_handler_config (struct SH_RequestHandler *rh,
     TALER_JSON_pack_amount ("annual_fee",
                             &SH_annual_fee),
     GNUNET_JSON_pack_string ("version",
-                             "2:0:0"));
+                             "2:1:0"));
 }
 
 
