@@ -1,6 +1,6 @@
 --
 -- This file is part of TALER
--- Copyright (C) 2021 Taler Systems SA
+-- Copyright (C) 2021, 2022 Taler Systems SA
 --
 -- TALER is free software; you can redistribute it and/or modify it under the
 -- terms of the GNU General Public License as published by the Free Software
@@ -17,18 +17,9 @@
 -- Everything in one big transaction
 BEGIN;
 
--- This script DROPs all of the tables we create.
---
--- Unlike the other SQL files, it SHOULD be updated to reflect the
--- latest requirements for dropping tables.
-
--- Drops for 0001.sql
-DROP TABLE IF EXISTS payments CASCADE;
-DROP TABLE IF EXISTS backups CASCADE;
-DROP TABLE IF EXISTS accounts CASCADE;
-
 -- Unregister patch (0001.sql)
 SELECT _v.unregister_patch('sync-0001');
+DROP SCHEMA sync CASCADE;
 
 -- And we're out of here...
 COMMIT;
