@@ -142,7 +142,7 @@ run (void *cls,
                                     "exchange-account-exchange"),
     TALER_TESTING_cmd_system_start ("start-taler",
                                     CONFIG_FILE,
-                                    "-emb",
+                                    "-embs",
                                     "-u", "exchange-account-exchange",
                                     NULL),
     TALER_TESTING_cmd_get_exchange ("get-exchange",
